# Copyright 2018-2020 Akretion France (http://www.akretion.com/)
# @author: Alexis de Lattre <alexis.delattre@akretion.com>
# License AGPL-3.0 or later (http://www.gnu.org/licenses/agpl).

import logging

from odoo import _, api, models
from odoo.exceptions import ValidationError

logger = logging.getLogger(__name__)

try:
    from stdnum.fr.nir import InvalidChecksum, InvalidFormat, InvalidLength, validate
except ImportError:
    logger.debug("Cannot import stdnum")


class HrEmployee(models.Model):
    _inherit = "hr.employee"

    @api.constrains("ssnid")
    def _check_france_ssnid(self):
        fr_country_codes = (
            "FR",
            "GP",
            "MQ",
            "GF",
            "RE",
            "YT",
            "PF",
            "PM",
            "MF",
            "BL",
            "NC",
        )
        for empl in self:
            if empl.company_id.country_id.code in fr_country_codes and empl.ssnid:
                try:
                    validate(empl.ssnid)
                except (InvalidFormat, InvalidLength, InvalidChecksum) as e:
                    raise ValidationError(
                        _(
                            "The French Social Security Number '%(ssnid)s' "
                            "is invalid. %(e)s"
                        )
                        % {"ssnid": empl.ssnid, "e": e}
                    ) from e
